summaryrefslogtreecommitdiffstats
path: root/kmobile/devices/skeleton/skeleton.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/devices/skeleton/skeleton.cpp')
-rw-r--r--kmobile/devices/skeleton/skeleton.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kmobile/devices/skeleton/skeleton.cpp b/kmobile/devices/skeleton/skeleton.cpp
index b5073de87..e6b1d9c59 100644
--- a/kmobile/devices/skeleton/skeleton.cpp
+++ b/kmobile/devices/skeleton/skeleton.cpp
@@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
/**
* The KDE skeleton mobile tqdevice driver.
*/
KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args )
: KMobileDevice(obj, name, args)
{
// set initial tqdevice info
setClassType( Phone );
- m_tqdeviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)");
- m_tqdeviceRevision = "0.1";
+ m_deviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)");
+ m_deviceRevision = "0.1";
setCapabilities( hasAddressBook | hasNotes );
}
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
{
}
// connect the tqdevice and ask user to turn tqdevice on (if necessary)
bool KMobileSkeleton::connectDevice(TQWidget *parent)
{
if (KMessageBox::Continue != KMessageBox::warningContinueCancel(parent,
- i18n("Please turn on your %1 on now and press continue to proceed.").tqarg(m_tqdeviceName),
- m_tqdeviceClassName ) )
+ i18n("Please turn on your %1 on now and press continue to proceed.").arg(m_deviceName),
+ m_deviceClassName ) )
return false;
// connect it now...
m_connected = true;
return m_connected;
}
// disconnect the tqdevice and return true, if sucessful
bool KMobileSkeleton::disconnectDevice(TQWidget *)
{
m_connected = true;
return true;
}
// returns true, if this tqdevice is read-only (default: false)
bool KMobileSkeleton::isReadOnly() const
{
return true;
@@ -87,7 +87,7 @@ bool KMobileSkeleton::isReadOnly() const
// return a unique ID, e.g. the IMEI number of phones, or a serial number
// this String is used to have a unique identification for syncronisation.
-TQString KMobileSkeleton::tqdeviceUniqueID()
+TQString KMobileSkeleton::deviceUniqueID()
{
return TQString::fromLocal8Bit("SkElEtOn-123456789");
}
@@ -112,7 +112,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
return KIO::ERR_DOES_NOT_EXIST;
// now build our own sample name
- addr.setFamilyName(TQString("Meyer_%1").tqarg(index+1));
+ addr.setFamilyName(TQString("Meyer_%1").arg(index+1));
addr.setGivenName("Peter");
addr.setFormattedName("Peter "+addr.familyName());
addr.setNickName("PeterM");
@@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool )
{
/* this is a read-only tqdevice */
return KIO::ERR_WRITE_ACCESS_DENIED;
}
@@ -156,8 +156,8 @@ int KMobileSkeleton::readNote( int index, TQString &note )
"DeviceClassName: %3\n"
"Device Driver : %4\n"
"Device Revision: %5\n")
- .tqarg(index).tqarg(index)
- .tqarg(tqdeviceClassName()).tqarg(tqdeviceName()).tqarg(revision());
+ .arg(index).arg(index)
+ .arg(deviceClassName()).arg(deviceName()).arg(revision());
return 0;
}
@@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
/**
- * The KDE skeleton mobile tqdevice driver.
+ * The KDE skeleton mobile device driver.
*/
KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args )
@@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
: KMobileDevice(obj, name, args)
{
- // set initial tqdevice info
+ // set initial device info
setClassType( Phone );
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
{
}
-// connect the tqdevice and ask user to turn tqdevice on (if necessary)
+// connect the device and ask user to turn device on (if necessary)
bool KMobileSkeleton::connectDevice(TQWidget *parent)
{
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
return m_connected;
}
-// disconnect the tqdevice and return true, if sucessful
+// disconnect the device and return true, if sucessful
bool KMobileSkeleton::disconnectDevice(TQWidget *)
{
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
return true;
}
-// returns true, if this tqdevice is read-only (default: false)
+// returns true, if this device is read-only (default: false)
bool KMobileSkeleton::isReadOnly() const
{
@@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool )
{
- /* this is a read-only tqdevice */
+ /* this is a read-only device */
return KIO::ERR_WRITE_ACCESS_DENIED;
}